@@ -1,9 +1,8 @@
 #[cfg(not(feature = "library"))]
 use cosmwasm_std::entry_point;
 use cosmwasm_std::{
-    attr, coin, to_binary, Addr, BankMsg, Binary, Decimal, Deps, DepsMut, DistributionMsg, Env,
-    MessageInfo, QuerierWrapper, Response, StakingMsg, StdError, StdResult, SubMsg, Uint128,
-    WasmMsg,
+    coin, to_binary, Addr, BankMsg, Binary, Decimal, Deps, DepsMut, DistributionMsg, Env,
+    MessageInfo, QuerierWrapper, Response, StakingMsg, StdError, StdResult, Uint128, WasmMsg,
 };
 
 use cw2::set_contract_version;
@@ -204,19 +203,15 @@ pub fn bond(deps: DepsMut, env: Env, info: MessageInfo) -> Result<Response, Cont
     execute_mint(deps, env, sub_info, info.sender.to_string(), to_mint)?;
 
     // bond them to the validator
-    let res = Response {
-        messages: vec![SubMsg::new(StakingMsg::Delegate {
+    let res = Response::new()
+        .add_message(StakingMsg::Delegate {
             validator: invest.validator,
             amount: payment.clone(),
-        })],
-        attributes: vec![
-            attr("action", "bond"),
-            attr("from", info.sender),
-            attr("bonded", payment.amount),
-            attr("minted", to_mint),
-        ],
-        ..Response::default()
-    };
+        })
+        .add_attribute("action", "bond")
+        .add_attribute("from", info.sender)
+        .add_attribute("bonded", payment.amount)
+        .add_attribute("minted", to_mint);
     Ok(res)
 }
 
@@ -282,19 +277,15 @@ pub fn unbond(
     )?;
 
     // unbond them
-    let res = Response {
-        messages: vec![SubMsg::new(StakingMsg::Undelegate {
+    let res = Response::new()
+        .add_message(StakingMsg::Undelegate {
             validator: invest.validator,
             amount: coin(unbond.u128(), &invest.bond_denom),
-        })],
-        attributes: vec![
-            attr("action", "unbond"),
-            attr("to", info.sender),
-            attr("unbonded", unbond),
-            attr("burnt", amount),
-        ],
-        ..Response::default()
-    };
+        })
+        .add_attribute("action", "unbond")
+        .add_attribute("to", info.sender)
+        .add_attribute("unbonded", unbond)
+        .add_attribute("burnt", amount);
     Ok(res)
 }
 
@@ -324,18 +315,14 @@ pub fn claim(deps: DepsMut, env: Env, info: MessageInfo) -> Result<Response, Con
 
     // transfer tokens to the sender
     balance.amount = to_send;
-    let res = Response {
-        messages: vec![SubMsg::new(BankMsg::Send {
+    let res = Response::new()
+        .add_message(BankMsg::Send {
             to_address: info.sender.to_string(),
             amount: vec![balance],
-        })],
-        attributes: vec![
-            attr("action", "claim"),
-            attr("from", info.sender),
-            attr("amount", to_send),
-        ],
-        ..Response::default()
-    };
+        })
+        .add_attribute("action", "claim")
+        .add_attribute("from", info.sender)
+        .add_attribute("amount", to_send);
     Ok(res)
 }
 
@@ -348,19 +335,15 @@ pub fn reinvest(deps: DepsMut, env: Env, _info: MessageInfo) -> Result<Response,
     let msg = to_binary(&ExecuteMsg::_BondAllTokens {})?;
 
     // and bond them to the validator
-    let res = Response {
-        messages: vec![
-            SubMsg::new(DistributionMsg::WithdrawDelegatorReward {
-                validator: invest.validator,
-            }),
-            SubMsg::new(WasmMsg::Execute {
-                contract_addr: contract_addr.to_string(),
-                msg,
-                funds: vec![],
-            }),
-        ],
-        ..Response::default()
-    };
+    let res = Response::new()
+        .add_message(DistributionMsg::WithdrawDelegatorReward {
+            validator: invest.validator,
+        })
+        .add_message(WasmMsg::Execute {
+            contract_addr: contract_addr.to_string(),
+            msg,
+            funds: vec![],
+        });
     Ok(res)
 }
 
@@ -396,14 +379,13 @@ pub fn _bond_all_tokens(
     }
 
     // and bond them to the validator
-    let res = Response {
-        messages: vec![SubMsg::new(StakingMsg::Delegate {
+    let res = Response::new()
+        .add_message(StakingMsg::Delegate {
             validator: invest.validator,
             amount: balance.clone(),
-        })],
-        attributes: vec![attr("action", "reinvest"), attr("bonded", balance.amount)],
-        ..Response::default()
-    };
+        })
+        .add_attribute("action", "reinvest")
+        .add_attribute("bonded", balance.amount);
     Ok(res)
 }
 
